---
title: <span class="badge object-type-scalar"></span> Celsius
---
# <span class="badge object-type-scalar"></span> Celsius

Temperature: Celsius (°C)

## Definition

```python
# Temperature: Celsius (°C)
Celsius: typing.Literal["celsius"] = "celsius"
```
